@@ -23,10 +23,10 @@ from os import path as _path
 
 from ._cache import clone_to_cache as _clone_to_cache
 
-REPOSITORY_PATH: str = _clone_to_cache("robot-assets")
+REPOSITORY_PATH: str = _clone_to_cache("roboschool")
 
-PACKAGE_PATH: str = _path.join(REPOSITORY_PATH, "urdfs", "robots", "fetch")
-
-MESHES_PATH: str = _path.join(PACKAGE_PATH, "meshes")
+PACKAGE_PATH: str = _path.join(
+    REPOSITORY_PATH, "roboschool", "models_robot", "fetch_description"
+)
 
 URDF_PATH: str = _path.join(PACKAGE_PATH, "robots", "fetch.urdf")
